==> ace_6.0.1.orig.tar.gz: ACE_wrappers/TAO/performance-tests/Sequence_Latency/AMH_Single_Threaded/Roundtrip.h <==
//
// $Id: Roundtrip.h 81968 2008-06-16 11:26:55Z sowayaa $
//

#ifndef ROUNDTRIP_H
#define ROUNDTRIP_H
#include /**/ "ace/pre.h"

#include "TestS.h"

#if defined (_MSC_VER)
# pragma warning(push)
# pragma warning (disable:4250)
#endif /* _MSC_VER */

/// Implement the Test::Roundtrip interface
class Roundtrip
  : public virtual POA_Test::AMH_Roundtrip
{
public:
  /// Constructor
  Roundtrip (CORBA::ORB_ptr orb);

  // = The skeleton methods
  void test_octet_method (Test::AMH_RoundtripResponseHandler_ptr _tao_rh,
                          const Test::octet_load& ol,
                          Test::Timestamp send_time);


  void test_long_method (Test::AMH_RoundtripResponseHandler_ptr _tao_rh,
                         const Test::long_load& ol,
                         Test::Timestamp send_time);

  void test_short_method (Test::AMH_RoundtripResponseHandler_ptr _tao_rh,
                          const Test::short_load& ol,
                          Test::Timestamp send_time);


  void test_char_method (Test::AMH_RoundtripResponseHandler_ptr _tao_rh,
                         const Test::char_load& ol,
                         Test::Timestamp send_time);

  void test_longlong_method (Test::AMH_RoundtripResponseHandler_ptr _tao_rh,
                             const Test::longlong_load& ol,
                             Test::Timestamp send_time);


  void test_double_method (Test::AMH_RoundtripResponseHandler_ptr _tao_rh,
                           const Test::double_load& ol,
                           Test::Timestamp send_time);



  void shutdown (Test::AMH_RoundtripResponseHandler_ptr _tao_rh);

private:
  /// Use an ORB reference to conver strings to objects and shutdown
  /// the application.
  CORBA::ORB_var orb_;
};

#if defined(_MSC_VER)
# pragma warning(pop)
#endif /* _MSC_VER */

#include /**/ "ace/post.h"
#endif /* ROUNDTRIP_H */

==> ace_6.5.4.orig.tar.gz: ACE_wrappers/TAO/performance-tests/Sequence_Latency/AMH_Single_Threaded/Roundtrip.h <==

#ifndef ROUNDTRIP_H
#define ROUNDTRIP_H
#include /**/ "ace/pre.h"

#include "TestS.h"

#if defined (_MSC_VER)
# pragma warning(push)
# pragma warning (disable:4250)
#endif /* _MSC_VER */

/// Implement the Test::Roundtrip interface
class Roundtrip
  : public virtual POA_Test::AMH_Roundtrip
{
public:
  /// Constructor
  Roundtrip (CORBA::ORB_ptr orb);

  // = The skeleton methods
  void test_octet_method (Test::AMH_RoundtripResponseHandler_ptr _tao_rh,
                          const Test::octet_load& ol,
                          Test::Timestamp send_time);


  void test_long_method (Test::AMH_RoundtripResponseHandler_ptr _tao_rh,
                         const Test::long_load& ol,
                         Test::Timestamp send_time);

  void test_short_method (Test::AMH_RoundtripResponseHandler_ptr _tao_rh,
                          const Test::short_load& ol,
                          Test::Timestamp send_time);


  void test_char_method (Test::AMH_RoundtripResponseHandler_ptr _tao_rh,
                         const Test::char_load& ol,
                         Test::Timestamp send_time);

  void test_longlong_method (Test::AMH_RoundtripResponseHandler_ptr _tao_rh,
                             const Test::longlong_load& ol,
                             Test::Timestamp send_time);


  void test_double_method (Test::AMH_RoundtripResponseHandler_ptr _tao_rh,
                           const Test::double_load& ol,
                           Test::Timestamp send_time);



  void shutdown (Test::AMH_RoundtripResponseHandler_ptr _tao_rh);

private:
  /// Use an ORB reference to convert strings to objects and shutdown
  /// the application.
  CORBA::ORB_var orb_;
};

#if defined(_MSC_VER)
# pragma warning(pop)
#endif /* _MSC_VER */

#include /**/ "ace/post.h"
#endif /* ROUNDTRIP_H */
